/**
 * Returns true if the passed value is null or undefined. This avoids errors
 * from JSLint complaining about use of ==, which can be technically
 * confusing.
 * ```ts
 * isNone();              // true
 * isNone(null);          // true
 * isNone(undefined);     // true
 * isNone('');            // false
 * isNone([]);            // false
 * isNone(function() {}); // false
 * ```
 * @note: copied from https://github.com/emberjs/ember.js/blob/5a8873bee19774a55fd0abfdcc7279f3efc768cd/packages/ember-metal/lib/is_none.ts#L25-L27
 */
export declare function isNone(obj: any): obj is null | undefined;
/**
 * Verifies that a value is null or undefined, an empty string, or an empty array.
 * Constrains the rules on isNone by returning true for empty strings and empty arrays.
 * If the value is an object with a size property of type number, it is used to check emptiness.
 * @param obj
 */
export declare function isEmpty(obj: any): obj is null | undefined | 0 | {
    size: 0;
} | [] | '';
/**
 * Check a value for blankness
 * @param obj value to check for blankness
 * @see isPresent
 */
export declare function isBlank(obj: any): boolean;
/**
 * Check a value for non-blankness
 * @param obj object to check for presence
 * @see isBlank
 */
export declare function isPresent(obj: any): boolean;
//# sourceMappingURL=checks.d.ts.map